@@ -45,13 +45,16 @@ def suiteFromPackage(name):
 
 def test_suite():
     suite = unittest.TestSuite()
-    for name in ['adapter', 'directive', 'grokker', 'order', 'testsetup',
-                 'util', 'utility', 'view', 'event']:
+    for name in ['adapter', 'directive', 'grokker', 'testsetup',
+                 'utility', 'view', 'event']:
         suite.addTest(suiteFromPackage(name))
 
-    suite.addTest(doctest.DocFileSuite(
-            'scan_for_module_components.txt',
-            optionflags=doctest.ELLIPSIS + doctest.NORMALIZE_WHITESPACE))
+    # this test cannot follow the normal testing pattern, as the
+    # bug it tests for is only exposed in the context of a doctest
+    grok_component = doctest.DocFileSuite('grok_component.txt',
+                                          setUp=setUpZope,
+                                          tearDown=cleanUpZope)
+    suite.addTest(grok_component)
     return suite
 
 if __name__ == '__main__':
